@@ -52,7 +52,7 @@ DEFAULTS = {
     'PURGE_LOG_BACKUP_BATCH': 20000,
     'PURGE_LOG_DELETE_BATCH': 1000,
     'TASK_LOGGER_NAME': 'security.task',
-    'TASK_USE_ON_SUCCESS': False,
+    'TASK_USE_PRE_COMMIT': False,
     'ELASTICSEARCH_DATABASE': None,
     'ELASTICSEARCH_AUTO_REFRESH': False,
     'BACKEND_WRITERS': None,
